fn print_test_outcome(name: &str, outcome: &TestOutcome)Expand description
Prints the complete status line and any detail output for a single test outcome.
fn print_test_outcome(name: &str, outcome: &TestOutcome)Prints the complete status line and any detail output for a single test outcome.